FirebaseGithubUpdaterHelper class

Helper class for easy app update integration Just call FirebaseGithubUpdaterHelper.checkAndShowUpdate() in your app

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

checkAndShowUpdate({required BuildContext context, required String collectionName, required String packageName, required String currentVersion, required int currentBuildNumber, VoidCallback? onUpdateComplete, VoidCallback? onNoUpdate, dynamic onError(dynamic error)?}) Future<void>
Check for updates and automatically show bottom sheet if available
hasUpdate({required String collectionName, required String packageName, required String currentVersion, required int currentBuildNumber}) Future<bool>
Silent check - only returns true/false if update available Useful for showing custom UI