AppRelease class

Constructors

AppRelease({required String id, required String packageName, required String appName, String repository = '', String repositoryUrl = '', String tag = '', required String version, required int buildNumber, String? description, String? releaseNotes, String? apkUrl, int? apkSize, required DateTime publishedAt, String? iconUrl, String channel = 'official', bool isBeta = false, List<DownloadAsset> downloads = const [], List<String> screenshots = const []})
AppRelease.fromJson(Map<String, dynamic> json)
factory

Properties

apkSize int?
final
apkUrl String?
final
appName String
final
availablePlatforms List<String>
no setter
buildNumber int
final
channel String
final
channelLabel String
no setter
description String?
final
downloads List<DownloadAsset>
final
downloadsByPlatform Map<String, List<DownloadAsset>>
no setter
formattedSize String
no setter
hasAndroid bool
no setter
hashCode int
The hash code for this object.
no setterinherited
hasLinux bool
no setter
hasMacOS bool
no setter
hasWindows bool
no setter
iconUrl String?
final
id String
final
isBeta bool
final
packageName String
final
publishedAt DateTime
final
releaseNotes String?
final
repository String
final
repositoryUrl String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenshots List<String>
final
shortDescription String
no setter
tag String
final
version String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited