DownloadAsset class

Represents a downloadable asset (APK, EXE, etc.)

Constructors

DownloadAsset({required String platform, required String type, String? arch, required String url, required String filename, required int size})
DownloadAsset.fromJson(Map<String, dynamic> json)
factory

Properties

arch String?
final
displayName String
no setter
filename String
final
formattedSize String
no setter
hashCode int
The hash code for this object.
no setterinherited
platform String
final
platformIcon IconData
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
final
type String
final
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited