DownloadProgress class

Constructors

DownloadProgress({required DownloadState state, double progress = 0, String? filePath, String? error})

Properties

error String?
final
filePath String?
final
hashCode int
The hash code for this object.
no setterinherited
progress double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state DownloadState
final

Methods

copyWith({DownloadState? state, double? progress, String? filePath, String? error}) DownloadProgress
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited