FirebaseUpdaterService class

Constructors

FirebaseUpdaterService({required String collectionName, required String currentVersion, required int currentBuildNumber, required String packageName, FirebaseFirestore? firestore})

Properties

collectionName String
final
currentBuildNumber int
final
currentVersion String
final
hashCode int
The hash code for this object.
no setterinherited
packageName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkForUpdate() Future<AppRelease?>
Check if update is available from Firestore
getAllReleases() Future<List<AppRelease>>
Get all releases for this app
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited