InstallService class

Constructors

InstallService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

canInstallApks() Future<bool>
Check if can install unknown apps
getDeviceArch() Future<String?>
Get device CPU architecture
getInstalledVersion(String packageName) Future<InstalledAppInfo?>
Get installed app version (checks both release and debug variants)
installApk(String filePath) Future<bool>
Install APK on Android
isAppInstalled(String packageName) Future<bool>
Check if app is installed (checks both release and debug variants)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openApp(String packageName) Future<bool>
Open installed app
openFile(String filePath) Future<bool>
Open file with system handler (for non-APK files)
requestInstallPermission() Future<bool>
Request install permission
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited