DownloadService class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancelAll(
) → void -
cancelDownload(
String url) → void -
downloadFile(
{required String url, required String filename}) → Stream< DownloadProgress> -
downloadWithProgress(
{required String url, required String filename, required dynamic onProgress(double), dynamic onSpeed(int)?, dynamic onComplete(int)?}) → Future< DownloadProgress> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited